<?php

/**
 * Music Library Manager - Main Page, Record List
 * 
 * This page is the main application page. It lists all records in the DB,
 * optoionally filtering them out by title, artist, year or genre (or a mix of
 * all). 
 * 
 * It contains links to add new records or edit existing ones. 
 *
 * Note that this page mostly contains presentation and usability logic and
 * uses backend classes for business logic and data management.  
 */

// Load application configuration
require_once '../config/jukebox-config.php';

// Load Song class
require_once '../library/JukeboxSong.php';

// Determine search mode (default to search in substrings)
if (isset($_GET['substrings']) && $_GET['substrings']==0) {
	$searchSubstrings = false;
} else {
	$searchSubstrings = true;
}

// Get list of songs from DB, passing the filters if set
$filters = (isset($_GET['filters']) ? $_GET['filters'] : array());
$songs = JukeboxSong::getSongList($filters, $searchSubstrings);
 

// Display HTML header
require_once 'common/html-top.php';
?>
	<h2>Song List</h2>
	
	<div class="filters">
		<form method="get">
			<h3>Seach Song</h3>

			<label for="filter-artist">Artist:</label>
			<input type="text" id="filter-artist" maxlength="72" name="filters[artist]" 
				value="<?php if (isset($filters['artist'])) echo htmlspecialchars($filters['artist']) ?>" />

			<label for="filter-title">Title:</label>
			<input type="text" id="filter-title" maxlength="72" name="filters[title]" 
				value="<?php if (isset($filters['title'])) echo htmlspecialchars($filters['title']) ?>" />
						
			<label for="filter-year">Year:</label>
			<input type="text" id="filter-year" size="4" maxlength="4" name="filters[year]" 
				value="<?php if (isset($filters['year'])) echo htmlspecialchars($filters['year']) ?>" />
			
			<label for="filter-genre">Genre:</label>
			<select id="filter-genre" name="filters[genre]">
				<option value="">- All -</option>
<?php foreach(JukeboxSong::getGenresList() as $genreId => $genre): 
    $slctd = (isset($filters['genre']) && $filters['genre'] == $genreId);
?>
				<option value="<?php echo $genreId; if ($slctd) echo '" selected="selected'; 
				    ?>"><?php echo htmlspecialchars($genre); ?></option> 
<?php endforeach; ?>
			</select>
			
			<label for="filter-substrings">Substrings:</label>
			<select id="filter-substrings" name="substrings">Substrings:
				<option value="0" <?php if (!$searchSubstrings) echo 'selected'; ?>>No</option>
				<option value="1" <?php if ($searchSubstrings) echo 'selected'; ?>>Yes</option>				
			</select>
			<input type="submit" id="filter-submit" value="Search &raquo;" />
			<a href="index.php">Reset</a>
		</form>
	</div>	
<?php if (empty($songs)): // No songs were found in the library ?>
	No songs were find in the library.
	
<?php else: // We do have songs?>
	<table class="songlist">
		<tr>
			<th>Artist</th>
			<th>Title</th>
			<th>Year</th>
			<th>Genre</th>
			<th>Actions</th>
		</tr>
		
<?php foreach($songs as $song): ?>
		<tr>
			<td><?php echo htmlspecialchars($song['artist']) ?></td>
			<td><?php echo htmlspecialchars($song['title']) ?></td>
			<td><?php echo $song['year'] ?></td>
			<td><?php echo htmlspecialchars($song['gen_desc']) ?></td>
			<td><a href="edit.php?songId=<?php echo (int) $song['id'] ?>">edit</a></td>
		</tr> 
<?php endforeach; ?>
	</table>
<?php endif; ?>

	<div class="table-actions">
		<a href="edit.php">Add a song &raquo;</a>
	</div>
<?php

// Display HTML footer
require_once 'common/html-bottom.php';
