<?php

/**
 * Music Library Management - Data Exception Class
 * 
 * A special exception class for invalid input data.
 * 
 * Contains an additional getFieldMessage() method that fetches an error 
 * message for a particular form field.
 */

class JukeboxDataException extends Exception 
{
    protected $_messages = array();
    
    /**
     * Set an error message for a particular form field
     *
     * @param string $field
     * @param string $message
     */
    public function setFieldMessage($field, $message)
    {
         $this->_messages[$field] = $message;
    }
    
    /**
     * Get an error message for a particular form field
     *
     * @param  string $field
     * @return string
     */
    public function getFieldMessage($field)
    {
        if (isset($this->_messages[$field])) {
            return $this->_messages[$field];
        } else {
            return null;
        }
    }
    
    /**
     * Get all error messages as an associative array
     * 
     * @return array
     */
    public function getAllFieldMessages()
    {
        return $this->_messages;
    }
}
