<?php

/**
 * Music Library Management App - Database Connection Wrapper Class
 *
 * This thing wrapper class wraps around a single PDO (connection) object using
 * the singleton pattern, and enables the entire app to use a central database connection
 * 
 * It contains a single ::getConnection() method.
 */

class JukeboxDb
{
    /**
     * Database connection adapter instance
     *
     * @var PDO
     */
    static protected $_instance = null;
    
    /**
     * Constructor is private - no instantiating this class
     *
     */
    private function __construct()
    { }
    
    /**
     * Prevent cloning of this class
     *
     */
    private function __clone()
    { }
    
    /**
     * Get the single db connection instance
     * 
     * @return PDO
     */
    static public function getConnection()
    {
       if (self::$_instance === null) {
           self::$_instance = new PDO(JBOX_DB_DSN, JBOX_DB_USER, JBOX_DB_PASSWORD);
           self::$_instance->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
       }
       
       return self::$_instance;
    }
}